diff --git a/app/Preferences.java b/app/Preferences.java
index 60d41ef9b..f49e4920b 100644
--- a/app/Preferences.java
+++ b/app/Preferences.java
@@ -300,6 +300,8 @@ public class Preferences {
box.add(label);
fontSizeField = new JTextField(4);
box.add(fontSizeField);
+ label = new JLabel(" (requires restart of Processing)");
+ box.add(label);
pain.add(box);
d = box.getPreferredSize();
box.setBounds(left, top, d.width, d.height);
diff --git a/build/macosx/dist/Processing.app/Contents/Info.plist b/build/macosx/dist/Processing.app/Contents/Info.plist
index 1b9a71ecf..c54e61640 100755
--- a/build/macosx/dist/Processing.app/Contents/Info.plist
+++ b/build/macosx/dist/Processing.app/Contents/Info.plist
@@ -55,7 +55,7 @@
JVMVersion
1.4*
ClassPath
- $JAVAROOT/pde.jar:lib/core.jar:$JAVAROOT/antlr.jar:$JAVAROOT/oro.jar:$JAVAROOT/registry.jar:lib/build
+ $JAVAROOT/pde.jar:lib/core.jar:$JAVAROOT/antlr.jar:$JAVAROOT/oro.jar:$JAVAROOT/registry.jar:$JAVAROOT/quaqua.jar:lib/build
Properties
diff --git a/build/macosx/run.sh b/build/macosx/run.sh
index a4155f97d..3a844d90e 100755
--- a/build/macosx/run.sh
+++ b/build/macosx/run.sh
@@ -1,9 +1,12 @@
#!/bin/sh
# is qt java already included tho?
-CLASSPATH=/System/Library/Java/Extensions/QTJava.zip:lib:lib/build:lib/pde.jar:lib/core.jar:lib/antlr.jar:lib/oro.jar:lib/registry.jar
+#CLASSPATH=/System/Library/Java/Extensions/QTJava.zip:lib:lib/build:lib/pde.jar:lib/core.jar:lib/antlr.jar:lib/oro.jar:lib/registry.jar
-export CLASSPATH
+#export CLASSPATH
#cd work && /System/Library/Frameworks/JavaVM.framework/Versions/1.4.2/Commands/java -Dapple.laf.useScreenMenuBar=true -Dapple.awt.showGrowBox=false processing.app.Base
-cd work && java -Dapple.laf.useScreenMenuBar=true -Dapple.awt.showGrowBox=false processing.app.Base
+#cd work && java -Dapple.laf.useScreenMenuBar=true -Dapple.awt.showGrowBox=false processing.app.Base
+
+# starting with work on release 0120, run directly from the .app
+cd work && ./Processing.app/Contents/MacOS/JavaApplicationStub
diff --git a/core/done.txt b/core/done.txt
index bbbfb013d..b72001b2f 100644
--- a/core/done.txt
+++ b/core/done.txt
@@ -1,3 +1,10 @@
+0119 core
+X add saveStream() method
+X change to handle Java 1.5 f-up where URLs now give FileNotFoundException
+X http://dev.processing.org/bugs/show_bug.cgi?id=403
+X add unlerp() method
+
+
0118 core
X replace jogl.jar with a signed version
X fix the export.txt file for the linux release
diff --git a/core/todo.txt b/core/todo.txt
index c65908e33..30bb18ea5 100644
--- a/core/todo.txt
+++ b/core/todo.txt
@@ -1,8 +1,4 @@
-0119 core
-X add saveStream() method
-X change to handle Java 1.5 f-up where URLs now give FileNotFoundException
-X http://dev.processing.org/bugs/show_bug.cgi?id=403
-X add unlerp() method
+0120 core
_ loadBytes() and saveStream() functions badly need optimization!
_ don't bother using a buffering stream, just handle internally. gah!
diff --git a/done.txt b/done.txt
index 8bd94e5ae..1f79a7ee8 100644
--- a/done.txt
+++ b/done.txt
@@ -1,3 +1,10 @@
+0119 pde
+X .java files weren't working in 116+
+X http://dev.processing.org/bugs/show_bug.cgi?id=405
+X need new copy of Capture example that has a new name
+X http://dev.processing.org/bugs/show_bug.cgi?id=408
+
+
0118 pde
X no changes, only an opengl export fix
diff --git a/todo.txt b/todo.txt
index 0b5a039a2..9e3af9da8 100644
--- a/todo.txt
+++ b/todo.txt
@@ -1,8 +1,6 @@
-0119 pde
-X .java files weren't working in 116+
-X http://dev.processing.org/bugs/show_bug.cgi?id=405
-X need new copy of Capture example that has a new name
-X http://dev.processing.org/bugs/show_bug.cgi?id=408
+0120 pde
+X add a note saying that changing the font size requires restart
+X add quaqua look and feel on the mac, improve how things look
_ createFont() should always use native fonts
_ need to warn that fonts may not be installed
diff --git a/app/Base.java b/app/Base.java
index a4f7dc895..f4d7bda9f 100644
--- a/app/Base.java
+++ b/app/Base.java
@@ -107,11 +107,18 @@ public class Base {
// set the look and feel before opening the window
try {
- if (Base.isLinux()) {
- // linux is by default (motif?) even uglier than metal
- // actually, i'm using native menus, so they're ugly and
- // motif-looking. ick. need to fix this.
- UIManager.setLookAndFeel(UIManager.getCrossPlatformLookAndFeelClassName());
+ if (Base.isMacOS()) {
+ // Use the Quaqua L & F on OS X to make JFileChooser less awful
+ UIManager.setLookAndFeel("ch.randelshofer.quaqua.QuaquaLookAndFeel");
+ UIManager.put("Component.visualMargin", new Insets(1, 1, 1, 1));
+
+ } else if (Base.isLinux()) {
+ // Linux is by default even uglier than metal (Motif?).
+ // Actually, i'm using native menus, so they're even uglier
+ // and Motif-looking (Lesstif?). Ick. Need to fix this.
+ String lfname = UIManager.getCrossPlatformLookAndFeelClassName();
+ UIManager.setLookAndFeel(lfname);
+
} else {
UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
}